@@ -113,7 +113,7 @@ class Manifest:
             self._ignore_path += os.path.sep
 
         self._hyperthought_root = hyperthought_root.replace("\\", "/")
-        self._hyperthought_root_id_path = None
+        self._hyperthought_root_id_path = ","
         self._database = None
         self._file_info_computed = False
 
@@ -298,6 +298,10 @@ class Manifest:
     def hyperthought_root_id_path(self) -> str:
         return self._hyperthought_root_id_path
 
+    @hyperthought_root_id_path.setter
+    def hyperthought_root_id_path(self, value: str) -> None:
+        self._hyperthought_root_id_path = value
+
     @property
     def file_info_computed(self) -> bool:
         return self._file_info_computed
